@@ -21,13 +21,14 @@
  *           Fax: +49 7123 / 14892
  *
  *
- *  $Id: dbdimp.h 1.1 Tue, 30 Sep 1997 01:28:08 +0200 joe $
+ *  $Id: dbdimp.h,v 1.2 1999/01/05 22:30:55 joe Exp $
  */
 
 /*
  *  Header files we use
  */
 #include <DBIXS.h>  /* installed by the DBI module                        */
+
 #include "myMsql.h"
 
 
@@ -52,7 +53,9 @@ enum errMsgs {
     JW_ERR_NO_RESULT,
     JW_ERR_NOT_IMPLEMENTED,
     JW_ERR_ILLEGAL_PARAM_NUM,
-    JW_ERR_MEM
+    JW_ERR_MEM,
+    JW_ERR_LIST_INDEX,
+    JW_ERR_SEQUENCE
 };
 
 
@@ -63,6 +66,7 @@ enum av_attribs {
     AV_ATTRIB_NAME = 0,
     AV_ATTRIB_TABLE,
     AV_ATTRIB_TYPE,
+    AV_ATTRIB_SQL_TYPE,
     AV_ATTRIB_IS_PRI_KEY,
     AV_ATTRIB_IS_NOT_NULL,
     AV_ATTRIB_NULLABLE,
@@ -112,6 +116,7 @@ struct imp_dbh_st {
     dbh_t svsock;           /*  socket number for msql, &mysql for
 			     *  mysql
 			     */
+    int compression;        /*  Using compression.  */
 };
 
 
@@ -151,9 +156,13 @@ struct imp_sth_st {
     int   insertid;       /* ID of auto insert                      */
     imp_sth_ph_t* params; /* Pointer to parameter array             */
     AV* av_attr[AV_ATTRIB_LAST];/*  For caching array attributes        */
+#ifdef DBD_MYSQL
     int   use_mysql_use_result;  /*  TRUE if execute should use     */
                           /* mysql_use_result rather than           */
                           /* mysql_store_result */
+#else
+  bool optimize;	  /* For Msql */
+#endif
 };
 
 
@@ -168,6 +177,7 @@ struct imp_sth_st {
 #define dbd_db_commit		mysql_db_commit
 #define dbd_db_rollback		mysql_db_rollback
 #define dbd_db_disconnect	mysql_db_disconnect
+#define dbd_discon_all		mysql_db_discon_all
 #define dbd_db_destroy		mysql_db_destroy
 #define dbd_db_STORE_attrib	mysql_db_STORE_attrib
 #define dbd_db_FETCH_attrib	mysql_db_FETCH_attrib
@@ -180,10 +190,42 @@ struct imp_sth_st {
 #define dbd_st_blob_read	mysql_st_blob_read
 #define dbd_st_STORE_attrib	mysql_st_STORE_attrib
 #define dbd_st_FETCH_attrib	mysql_st_FETCH_attrib
+#define dbd_st_FETCH_internal	mysql_st_FETCH_internal
 #define dbd_describe		mysql_describe
 #define dbd_bind_ph		mysql_bind_ph
+#define BindParam		mysql_st_bind_param
 #define dbd_st_internal_execute mysql_st_internal_execute
 #define mymsql_constant         mysql_constant
+#define do_warn			mysql_dr_warn
+#define do_error		mysql_dr_error
+#elif defined(DBD_MSQL1)
+#define dbd_init		msql1_dr_init
+#define dbd_db_login		msql1_db_login
+#define dbd_db_do		msql1_db_do
+#define dbd_db_commit		msql1_db_commit
+#define dbd_db_rollback		msql1_db_rollback
+#define dbd_db_disconnect	msql1_db_disconnect
+#define dbd_discon_all		msql1_db_discon_all
+#define dbd_db_destroy		msql1_db_destroy
+#define dbd_db_STORE_attrib	msql1_db_STORE_attrib
+#define dbd_db_FETCH_attrib	msql1_db_FETCH_attrib
+#define dbd_st_prepare		msql1_st_prepare
+#define dbd_st_rows		msql1_st_rows
+#define dbd_st_execute		msql1_st_execute
+#define dbd_st_fetch		msql1_st_fetch
+#define dbd_st_finish		msql1_st_finish
+#define dbd_st_destroy		msql1_st_destroy
+#define dbd_st_blob_read	msql1_st_blob_read
+#define dbd_st_STORE_attrib	msql1_st_STORE_attrib
+#define dbd_st_FETCH_attrib	msql1_st_FETCH_attrib
+#define dbd_st_FETCH_internal	msql1_st_FETCH_internal
+#define dbd_describe		msql1_describe
+#define dbd_bind_ph		msql1_bind_ph
+#define BindParam		msql1_st_bind_param
+#define dbd_st_internal_execute msql1_st_internal_execute
+#define mymsql_constant         msql1_constant
+#define do_warn			msql1_dr_warn
+#define do_error		msql1_dr_error
 #else
 #define dbd_init		msql_dr_init
 #define dbd_db_login		msql_db_login
@@ -191,6 +233,7 @@ struct imp_sth_st {
 #define dbd_db_commit		msql_db_commit
 #define dbd_db_rollback		msql_db_rollback
 #define dbd_db_disconnect	msql_db_disconnect
+#define dbd_discon_all		msql_db_discon_all
 #define dbd_db_destroy		msql_db_destroy
 #define dbd_db_STORE_attrib	msql_db_STORE_attrib
 #define dbd_db_FETCH_attrib	msql_db_FETCH_attrib
@@ -203,10 +246,14 @@ struct imp_sth_st {
 #define dbd_st_blob_read	msql_st_blob_read
 #define dbd_st_STORE_attrib	msql_st_STORE_attrib
 #define dbd_st_FETCH_attrib	msql_st_FETCH_attrib
+#define dbd_st_FETCH_internal	msql_st_FETCH_internal
 #define dbd_describe		msql_describe
 #define dbd_bind_ph		msql_bind_ph
+#define BindParam		msql_st_bind_param
 #define dbd_st_internal_execute msql_st_internal_execute
 #define mymsql_constant         msql_constant
+#define do_warn			msql_dr_warn
+#define do_error		msql_dr_error
 #endif
 
 #include <dbd_xsh.h>
@@ -214,6 +261,12 @@ void	 do_error _((SV* h, int rc, char *what));
 SV	*dbd_db_fieldlist _((result_t res));
 
 void    dbd_preparse _((imp_sth_t *imp_sth, SV *statement));
+#ifdef DBD_MYSQL
 int dbd_st_internal_execute(SV*, SV*, SV*, int, imp_sth_ph_t*, result_t*,
 			    dbh_t, int);
+#else
+int dbd_st_internal_execute(SV*, SV*, SV*, int, imp_sth_ph_t*, result_t*,
+			    dbh_t);
+#endif
 
+extern int MysqlReconnect(SV*);
